@@ -6,14 +6,12 @@
  * Adapted by Steve Underwood <steveu@coppice.org> from the reference
  * code supplied with ITU G.722.1, which is:
  *
- *    2004 Polycom, Inc.
+ *   (C)2004 Polycom, Inc.
  *   All rights reserved.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *
- * $Id: decoder.c,v 1.23 2008/11/27 12:52:10 steveu Exp $
  */
 
 /*! \file */
@@ -587,7 +585,7 @@ static void error_handling(int16_t number_of_coefs,
 }
 /*- End of function --------------------------------------------------------*/
 
-int g722_1_decode(g722_1_decode_state_t *s, int16_t amp[], const uint8_t g722_1_data[], int len)
+G722_1_DECLARE(int) g722_1_decode(g722_1_decode_state_t *s, int16_t amp[], const uint8_t g722_1_data[], int len)
 {
     int16_t decoder_mlt_coefs[MAX_DCT_LENGTH];
     int16_t mag_shift;
@@ -616,7 +614,7 @@ int g722_1_decode(g722_1_decode_state_t *s, int16_t amp[], const uint8_t g722_1_
 }
 /*- End of function --------------------------------------------------------*/
 
-int g722_1_fillin(g722_1_decode_state_t *s, int16_t amp[], const uint8_t g722_1_data[], int len)
+G722_1_DECLARE(int) g722_1_fillin(g722_1_decode_state_t *s, int16_t amp[], const uint8_t g722_1_data[], int len)
 {
     int16_t decoder_mlt_coefs[MAX_DCT_LENGTH];
     int16_t mag_shift;
@@ -648,7 +646,7 @@ int g722_1_fillin(g722_1_decode_state_t *s, int16_t amp[], const uint8_t g722_1_
 /*- End of function --------------------------------------------------------*/
 #endif
 
-int g722_1_decode_set_rate(g722_1_decode_state_t *s, int bit_rate)
+G722_1_DECLARE(int) g722_1_decode_set_rate(g722_1_decode_state_t *s, int bit_rate)
 {
     if ((bit_rate < 16000)  ||  (bit_rate > 48000)  ||  ((bit_rate%800) != 0))
         return -1;
@@ -659,7 +657,7 @@ int g722_1_decode_set_rate(g722_1_decode_state_t *s, int bit_rate)
 }
 /*- End of function --------------------------------------------------------*/
 
-g722_1_decode_state_t *g722_1_decode_init(g722_1_decode_state_t *s, int bit_rate, int sample_rate)
+G722_1_DECLARE(g722_1_decode_state_t *) g722_1_decode_init(g722_1_decode_state_t *s, int bit_rate, int sample_rate)
 {
 #if !defined(G722_1_USE_FIXED_POINT)
     int i;
@@ -708,7 +706,7 @@ g722_1_decode_state_t *g722_1_decode_init(g722_1_decode_state_t *s, int bit_rate
 }
 /*- End of function --------------------------------------------------------*/
 
-int g722_1_decode_release(g722_1_decode_state_t *s)
+G722_1_DECLARE(int) g722_1_decode_release(g722_1_decode_state_t *s)
 {
     free(s);
     return 0;
