@@ -6,14 +6,12 @@
  * Adapted by Steve Underwood <steveu@coppice.org> from the reference
  * code supplied with ITU G.722.1, which is:
  *
- *    2004 Polycom, Inc.
+ *   (C) 2004 Polycom, Inc.
  *   All rights reserved.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *
- * $Id: decoderf.c,v 1.25 2008/11/25 13:54:22 steveu Exp $
  */
 
 /*! \file */
@@ -574,7 +572,7 @@ static void error_handling(int number_of_coefs,
 }
 /*- End of function --------------------------------------------------------*/
 
-int g722_1_decode(g722_1_decode_state_t *s, int16_t amp[], const uint8_t g722_1_data[], int len)
+G722_1_DECLARE(int) g722_1_decode(g722_1_decode_state_t *s, int16_t amp[], const uint8_t g722_1_data[], int len)
 {
     float decoder_mlt_coefs[MAX_DCT_LENGTH];
     float famp[MAX_FRAME_SIZE];
@@ -609,7 +607,7 @@ int g722_1_decode(g722_1_decode_state_t *s, int16_t amp[], const uint8_t g722_1_
 }
 /*- End of function --------------------------------------------------------*/
 
-int g722_1_fillin(g722_1_decode_state_t *s, int16_t amp[], const uint8_t g722_1_data[], int len)
+G722_1_DECLARE(int) g722_1_fillin(g722_1_decode_state_t *s, int16_t amp[], const uint8_t g722_1_data[], int len)
 {
     float decoder_mlt_coefs[MAX_DCT_LENGTH];
     float famp[MAX_FRAME_SIZE];
