@@ -6,14 +6,12 @@
  * Adapted by Steve Underwood <steveu@coppice.org> from the reference
  * code supplied with ITU G.722.1, which is:
  *
- *    2004 Polycom, Inc.
+ *   (C) 2004 Polycom, Inc.
  *   All rights reserved.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *
- * $Id: encoder.c,v 1.29 2008/11/27 12:52:10 steveu Exp $
  */
 
 /*! \file */
@@ -618,7 +616,7 @@ static int16_t vector_huffman(int16_t category,
 }
 /*- End of function --------------------------------------------------------*/
 
-int g722_1_encode(g722_1_encode_state_t *s, uint8_t g722_1_data[], const int16_t amp[], int len)
+G722_1_DECLARE(int) g722_1_encode(g722_1_encode_state_t *s, uint8_t g722_1_data[], const int16_t amp[], int len)
 {
     int16_t mlt_coefs[MAX_FRAME_SIZE];
     int16_t mag_shift;
@@ -640,7 +638,7 @@ int g722_1_encode(g722_1_encode_state_t *s, uint8_t g722_1_data[], const int16_t
 /*- End of function --------------------------------------------------------*/
 #endif
 
-int g722_1_encode_set_rate(g722_1_encode_state_t *s, int bit_rate)
+G722_1_DECLARE(int) g722_1_encode_set_rate(g722_1_encode_state_t *s, int bit_rate)
 {
     if ((bit_rate < 16000)  ||  (bit_rate > 48000)  ||  ((bit_rate%800) != 0))
         return -1;
@@ -651,7 +649,7 @@ int g722_1_encode_set_rate(g722_1_encode_state_t *s, int bit_rate)
 }
 /*- End of function --------------------------------------------------------*/
 
-g722_1_encode_state_t *g722_1_encode_init(g722_1_encode_state_t *s, int bit_rate, int sample_rate)
+G722_1_DECLARE(g722_1_encode_state_t *) g722_1_encode_init(g722_1_encode_state_t *s, int bit_rate, int sample_rate)
 {
 #if !defined(G722_1_USE_FIXED_POINT)
     int i;
@@ -695,7 +693,7 @@ g722_1_encode_state_t *g722_1_encode_init(g722_1_encode_state_t *s, int bit_rate
 }
 /*- End of function --------------------------------------------------------*/
 
-int g722_1_encode_release(g722_1_encode_state_t *s)
+G722_1_DECLARE(int) g722_1_encode_release(g722_1_encode_state_t *s)
 {
     free(s);
     return 0;
