@@ -6,14 +6,12 @@
  * Adapted by Steve Underwood <steveu@coppice.org> from the reference
  * code supplied with ITU G.722.1, which is:
  *
- *    2004 Polycom, Inc.
+ *   (C) 2004 Polycom, Inc.
  *   All rights reserved.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *
- * $Id: encoderf.c,v 1.24 2008/11/25 13:45:01 steveu Exp $
  */
 
 /*! \file */
@@ -487,7 +485,7 @@ static int vector_huffman(int category,
 }
 /*- End of function --------------------------------------------------------*/
 
-int g722_1_encode(g722_1_encode_state_t *s, uint8_t g722_1_data[], const int16_t amp[], int len)
+G722_1_DECLARE(int) g722_1_encode(g722_1_encode_state_t *s, uint8_t g722_1_data[], const int16_t amp[], int len)
 {
     float mlt_coefs[MAX_FRAME_SIZE];
     float famp[MAX_FRAME_SIZE];
